@@ -1,4 +1,5 @@
-/* Copyright 1999-2004 The Apache Software Foundation
+/* Copyright 1999-2005 The Apache Software Foundation or its licensors, as
+ * applicable.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -520,7 +521,7 @@ static const char *log_request_time(request_rec *r, char *a)
             char sign;
             int timz;
 
-            ap_explode_recent_localtime(&xt, r->request_time);
+            ap_explode_recent_localtime(&xt, request_time);
             timz = xt.tm_gmtoff;
             if (timz < 0) {
                 timz = -timz;
