@@ -707,7 +707,7 @@ PROXY_DECLARE(int) ap_proxy_is_ipaddr(struct dirconn_entry *This, apr_pool_t *p)
 
 	if (bits != 32)		/* no warning for fully qualified IP address */
             ap_log_error(APLOG_MARK, APLOG_STARTUP, 0, NULL,
-	      "Warning: NetMask not supplied with IP-Addr; guessing: %s/%ld\n",
+	      "Warning: NetMask not supplied with IP-Addr; guessing: %s/%ld",
 		 inet_ntoa(This->addr), bits);
     }
 
@@ -715,11 +715,11 @@ PROXY_DECLARE(int) ap_proxy_is_ipaddr(struct dirconn_entry *This, apr_pool_t *p)
 
     if (*addr == '\0' && (This->addr.s_addr & ~This->mask.s_addr) != 0) {
         ap_log_error(APLOG_MARK, APLOG_STARTUP, 0, NULL,
-	    "Warning: NetMask and IP-Addr disagree in %s/%ld\n",
+	    "Warning: NetMask and IP-Addr disagree in %s/%ld",
 		inet_ntoa(This->addr), bits);
 	This->addr.s_addr &= This->mask.s_addr;
         ap_log_error(APLOG_MARK, APLOG_STARTUP, 0, NULL,
-	    "         Set to %s/%ld\n",
+	    "         Set to %s/%ld",
 		inet_ntoa(This->addr), bits);
     }
 
