@@ -1,4 +1,5 @@
-/* Copyright 2001-2004 The Apache Software Foundation
+/* Copyright 2001-2005 The Apache Software Foundation or its licensors, as
+ * applicable.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -1092,7 +1093,7 @@ AP_DECLARE(int) ap_directory_walk(request_rec *r)
  x symlink above into a real resource, and should have died up there.
  x Even if we keep this, it needs more thought (maybe an r->file_is_symlink)
  x perhaps it should actually happen in file_walk, so we catch more
- x obscure cases in autoindex sub requests, etc.
+ x obscure cases in autoindex subrequests, etc.
  x
  x    * Symlink permissions are determined by the parent.  If the request is
  x    * for a directory then applying the symlink test here would use the
@@ -1567,7 +1568,7 @@ AP_DECLARE(int) ap_some_auth_required(request_rec *r)
 
 
 AP_DECLARE(request_rec *) ap_sub_req_method_uri(const char *method,
-                                                const char *new_file,
+                                                const char *new_uri,
                                                 const request_rec *r,
                                                 ap_filter_t *next_filter)
 {
@@ -1581,13 +1582,13 @@ AP_DECLARE(request_rec *) ap_sub_req_method_uri(const char *method,
     rnew->method = method;
     rnew->method_number = ap_method_number_of(method);
 
-    if (new_file[0] == '/') {
-        ap_parse_uri(rnew, new_file);
+    if (new_uri[0] == '/') {
+        ap_parse_uri(rnew, new_uri);
     }
     else {
         udir = ap_make_dirstr_parent(rnew->pool, r->uri);
         udir = ap_escape_uri(rnew->pool, udir);    /* re-escape it */
-        ap_parse_uri(rnew, ap_make_full_path(rnew->pool, udir, new_file));
+        ap_parse_uri(rnew, ap_make_full_path(rnew->pool, udir, new_uri));
     }
 
     /* We cannot return NULL without violating the API. So just turn this
@@ -1612,11 +1613,11 @@ AP_DECLARE(request_rec *) ap_sub_req_method_uri(const char *method,
     return rnew;
 }
 
-AP_DECLARE(request_rec *) ap_sub_req_lookup_uri(const char *new_file,
+AP_DECLARE(request_rec *) ap_sub_req_lookup_uri(const char *new_uri,
                                                 const request_rec *r,
                                                 ap_filter_t *next_filter)
 {
-    return ap_sub_req_method_uri("GET", new_file, r, next_filter);
+    return ap_sub_req_method_uri("GET", new_uri, r, next_filter);
 }
 
 AP_DECLARE(request_rec *) ap_sub_req_lookup_dirent(const apr_finfo_t *dirent,
